@@ -7,6 +7,7 @@
 #' @param service vector of service times. Leave as zero if you want to compute the number of customers in the system rather than queue length.
 #' @param departures vector of departure times
 #' @param epsilon numeric small number added to departures to prevent negative queue lengths
+#' @param ... additional arguments - does nothing, for compatibility
 #' @examples
 #' library(dplyr)
 #' library(queuecomputer)
@@ -60,7 +61,7 @@
 #'       aes(x = times, y = queuelength) + geom_step() +
 #'       facet_grid(~route)
 #' }
-queue_lengths <- function(arrivals, service = 0, departures, epsilon = 1e-10){
+queue_lengths <- function(arrivals, service = 0, departures, epsilon = 1e-10, ...){
 
   if(length(service) == 1){
     stopifnot(service == 0)
@@ -79,31 +80,8 @@ queue_lengths <- function(arrivals, service = 0, departures, epsilon = 1e-10){
     queuelength = cumsum(.subset(qd_state, out$ix))
   )
 
-  return(queuedata)
-
-}
-
-queue_lengths_old <- function(arrivals, service = 0, departures){
-
-  if(length(service) == 1){
-    stopifnot(service == 0)
-    check_queueinput(arrivals, service = departures)
-  } else {
-    check_queueinput(arrivals, service, departures)
-  }
-
-  queuedata <- data.frame(
-    times = c(0, arrivals, departures - service),
-    state = c(0L, rep.int(1L, length(arrivals)), rep.int(-1L, length(arrivals))
-    ))
-
-  ord <- order(queuedata$times, queuedata$state * -1L, method = "radix")
-
-  queuedata <- queuedata[ord, ]
-
-  queuedata$queuelength <- cumsum(queuedata$state)
-
-  queuedata <- queuedata[c("times", "queuelength")]
+  # For compatability
+  #queuedata$queuelength <- queuedata$value
 
   return(queuedata)
 
@@ -122,7 +100,7 @@ queue_lengths_old <- function(arrivals, service = 0, departures){
 #' average_queue(queuedata$times, queuedata$queuelength)
 #' @export
 average_queue <- function(times, queuelength){
-  ((c(diff(times),0) %*% queuelength) / (times[length(times)] - times[1])) %>% as.numeric()
+  as.numeric((c(diff(times),0) %*% queuelength) / (times[length(times)] - times[1]))
 }
 
 #' Summarise queue lengths
@@ -174,51 +152,6 @@ ql_summary <- function(times, queuelength){
 # }
 
 
-#' Creates batches of customer arrivals from a dataframe within a \code{dplyr::do} command
-#'
-#' @param data a dataframe with parameters for each batch
-#' @param arrival_dist a distribution whose support is strictly positive. Either as an object or a non-empty character string. It represents the distribution of arrival times.
-#' @param service_rate a strictly positive number representing the rate parameter in the exponential distribution for the service times.
-#' @param time a number greater than or equal to zero.
-#' @export
-#' @examples
-#'
-#' library(dplyr)
-#' flight_schedule <- data_frame(
-#' flight = c("F1", "F2"),
-#' time = c(0, 50),
-#' n = c(100, 100),
-#' shape = c(5, 5),
-#' rate = c(1 , 1),
-#' log_mu = c(1 , 1)
-#' )
-#'
-#' passenger_df <- flight_schedule %>% group_by(flight) %>%
-#' do(create_batches(., arrival_dist = "rgamma",
-#'     service_rate = 0.4,
-#'     time = .$time)
-#' )
-#'
-#' queue_obj <- with(passenger_df,
-#'     queue_step(arrivals, service, servers = 5)
-#' )
-#' if(require(ggplot2, quietly = TRUE)){
-#'     plot(queue_obj)
-#' }
-#'
-create_batches <- function(data, arrival_dist, service_rate = NULL, time = 0){
-
-  output_df <- dplyr::data_frame(arrivals = time + do_func_ignore_things(data, arrival_dist))
-
-  if(is.null(service_rate) == FALSE){
-    output_df <- output_df %>% dplyr::mutate(
-      service = stats::rexp(data$n, service_rate)
-    )
-  }
-  return(output_df)
-}
-
-
 
 
 
